RuCOS Task
Users can initialize tasks using Task::new, providing an identifier (Task::id) and a task priority. The Task must have static lifetime and the idenfitier must be a unique integer in the range [0:MAX_NUM_TASKS).
Task::new
Task::id
Task
static
[0:MAX_NUM_TASKS)